@@ -25,6 +25,9 @@ class DiagramMetrix(blockdiag.DiagramMetrix.DiagramMetrix):
         super(DiagramMetrix, self).__init__(diagram, **kwargs)
 
         self.setdefault('networks', diagram.networks)
+        self.setdefault('trunk_diameter', self['cellSize'])
+        self.setdefault('jump_shift', self['trunk_diameter'] / 2)
+        self.setdefault('jump_radius', self['trunk_diameter'])
 
         if diagram.page_padding is None and kwargs.get('pagePadding') is None:
             top_padding = self['spanHeight']
@@ -120,12 +123,17 @@ class NodeMetrix(object):
 
         for networks in [above, bottom]:
             for network in networks:
+                if network.hidden:
+                    span = 0
+                else:
+                    span = m.trunk_diameter / 2
+
                 if network.xy.y <= self.node.xy.y:
                     x, y2 = self.top()
-                    y1 = m.network(network).top().y
+                    y1 = m.network(network).top().y + span
                 else:
                     x, y1 = self.bottom()
-                    y2 = m.network(network).top().y
+                    y2 = m.network(network).top().y - span
 
                 if len(networks) == 1:
                     dx = 0
